package org.dromara.ems.report.mapper;

import org.dromara.ems.report.domain.EmsReportPointSteam;

import java.util.List;

/**
 * 蒸汽整点数据Mapper接口
 *
 * @author Yinq
 * @date 2024-06-11
 */
public interface EmsReportPointSteamMapper {
    /**
     * 查询蒸汽整点数据
     *
     * @param objId 蒸汽整点数据主键
     * @return 蒸汽整点数据
     */
    public EmsReportPointSteam selectEmsReportPointSteamByObjId(Long objId);

    /**
     * 查询蒸汽整点数据列表
     *
     * @param emsReportPointSteam 蒸汽整点数据
     * @return 蒸汽整点数据集合
     */
    public List<EmsReportPointSteam> selectEmsReportPointSteamList(EmsReportPointSteam emsReportPointSteam);

    /**
     * 新增蒸汽整点数据
     *
     * @param emsReportPointSteam 蒸汽整点数据
     * @return 结果
     */
    public int insertEmsReportPointSteam(EmsReportPointSteam emsReportPointSteam);

    /**
     * 修改蒸汽整点数据
     *
     * @param emsReportPointSteam 蒸汽整点数据
     * @return 结果
     */
    public int updateEmsReportPointSteam(EmsReportPointSteam emsReportPointSteam);

    /**
     * 删除蒸汽整点数据
     *
     * @param objId 蒸汽整点数据主键
     * @return 结果
     */
    public int deleteEmsReportPointSteamByObjId(Long objId);

    /**
     * 批量删除蒸汽整点数据
     *
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEmsReportPointSteamByObjIds(Long[] objIds);
}
